@@ -1,6 +1,5 @@
 from contextlib import contextmanager
-from numbers import Number
-from time import sleep
+from threading import Lock
 from bisect import bisect_left
 from itertools import combinations_with_replacement
 from typing import Collection
@@ -38,11 +37,13 @@ class PrimeNumbers(object):
     Creates a cache of known primes which is accessed by all active instances
     
     Use n in PrimeNumbers() to test whether n is prime
+
+    Use with test_wrapper() to reset cache for testing purposes
     """
 
     _knownprimes = [1,2,3,5,7]
     
-    _lock = False
+    _testlock = Lock()
 
     _prime = None
 
@@ -180,18 +181,19 @@ class PrimeNumbers(object):
     @classmethod
     @contextmanager
     def test_wrapper(cls):
-        while cls._lock:
-            sleep(1)
-        cls._lock = True
+        """Locking and resetting cache of known primes. Designed purely for using in tests
+        
+        Acquires a lock, resets cache, yields for tests then resets cache again and releases lock
+        """
+        with cls._testlock:
+            cls._prime = cls._generateprimes()
+            cls._knownprimes = [1,2,3,5,7]
 
-        cls._prime = cls._generateprimes()
-        cls._knownprimes = [1,2,3,5,7]
+            yield
 
-        yield
-
-        cls._prime = cls._generateprimes()
-        cls._knownprimes = [1,2,3,5,7]
-        cls._lock = False
+            cls._prime = cls._generateprimes()
+            cls._knownprimes = [1,2,3,5,7]
+        
 
 def primesieve(n: int) -> list:
     """Returns a list of all primes < n
